<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 1/6/2010	ELL
// Revised: 2/10/2012	ELL
// Added table prefix handling.
// Revised: 3/23/2015	ELL
// Added updating of mobile menu description.
// Revised: 2/26/2018	ELL
// Added 3rd menu category for systems that ane not mobile (cell phones) but have touchscreens.
// 
// 
	include ("check_session.php");
	
	$menu_name = $_POST['selectMenu2'];
	$description = $_POST['new_description'];

	if (($menu_name != "") && isset($menu_name))
	{	
		$query = "UPDATE `" . BWB_TABLE_PREFIX . "menus` SET `description` = '" . $description . "' WHERE `menu_name` = '" . $menu_name . "'";
		$cnt = $bwb_dbh->exec($query);
		
		$query = "UPDATE `" . BWB_TABLE_PREFIX . "menus` SET `description` = '" . $description . " Mobile' WHERE `menu_name` = '" . $menu_name . "_mobile'";
		$cnt = $bwb_dbh->exec($query);
		
		$query = "UPDATE `" . BWB_TABLE_PREFIX . "menus` SET `description` = '" . $description . " Touchscreen' WHERE `menu_name` = '" . $menu_name . "_touchscreen'";
		$cnt = $bwb_dbh->exec($query);
	}
	
	header("Location: manage_menu.php?menu=$menu_name");
	
?>
